@@ -23,51 +23,52 @@ This package holds all available charts in pygal, the Config class
 and the maps extensions namespace module.
 
 """
+from .__about__ import *  # noqa: F401,F403 isort: skip
 
-__version__ = '2.3.1'
-
-import pkg_resources
 import sys
 import traceback
 import warnings
+from importlib.metadata import entry_points
 
+from pygal import maps
+from pygal.config import Config
 from pygal.graph.bar import Bar
 from pygal.graph.box import Box
 from pygal.graph.dot import Dot
 from pygal.graph.funnel import Funnel
 from pygal.graph.gauge import Gauge
-from pygal.graph.solidgauge import SolidGauge
+from pygal.graph.graph import Graph
 from pygal.graph.histogram import Histogram
 from pygal.graph.horizontalbar import HorizontalBar
-from pygal.graph.horizontalstackedbar import HorizontalStackedBar
-from pygal.graph.line import Line
 from pygal.graph.horizontalline import HorizontalLine
+from pygal.graph.horizontalstackedbar import HorizontalStackedBar
 from pygal.graph.horizontalstackedline import HorizontalStackedLine
+from pygal.graph.line import Line
 from pygal.graph.pie import Pie
 from pygal.graph.pyramid import Pyramid, VerticalPyramid
 from pygal.graph.radar import Radar
+from pygal.graph.solidgauge import SolidGauge
 from pygal.graph.stackedbar import StackedBar
 from pygal.graph.stackedline import StackedLine
-from pygal.graph.time import DateLine, DateTimeLine, TimeLine, TimeDeltaLine
+from pygal.graph.time import DateLine, DateTimeLine, TimeDeltaLine, TimeLine
 from pygal.graph.treemap import Treemap
 from pygal.graph.xy import XY
-from pygal.graph.graph import Graph
-from pygal.config import Config
-from pygal import maps
-
-
-CHARTS_BY_NAME = dict(
-    [(k, v) for k, v in locals().items()
-     if isinstance(v, type) and issubclass(v, Graph) and v != Graph])
 
+CHARTS_BY_NAME = dict([
+    (k, v) for k, v in locals().items()
+    if isinstance(v, type) and issubclass(v, Graph) and v != Graph
+])
 
 from pygal.graph.map import BaseMap
-for entry in pkg_resources.iter_entry_points('pygal.maps'):
+
+for entry in entry_points().get('pygal.maps', ()):
     try:
         module = entry.load()
     except Exception:
-        warnings.warn('Unable to load %s pygal plugin \n\n%s' % (
-            entry, traceback.format_exc()), Warning)
+        warnings.warn(
+            'Unable to load %s pygal plugin \n\n%s' %
+            (entry, traceback.format_exc()), Warning
+        )
         continue
     setattr(maps, entry.name, module)
     for k, v in module.__dict__.items():
@@ -79,7 +80,6 @@ CHARTS = list(CHARTS_BY_NAME.values())
 
 
 class PluginImportFixer(object):
-
     """
     Allow external map plugins to be imported from pygal.maps package.
 
@@ -106,4 +106,5 @@ class PluginImportFixer(object):
             sys.modules[name] = getattr(maps, name.split('.')[2])
         return sys.modules[name]
 
+
 sys.meta_path += [PluginImportFixer()]
